@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2015 OpenStack Foundation.
 # All Rights Reserved.
@@ -19,14 +18,8 @@ import abc
 import ast
 import inspect
 
-import six
 import stevedore
 
-if hasattr(inspect, 'getfullargspec'):
-    getargspec = inspect.getfullargspec
-else:
-    getargspec = inspect.getargspec
-
 registered_checks = {}
 extension_checks = None
 
@@ -78,7 +71,7 @@ def _check(rule, target, creds, enforcer, current_rule):
 
     """
     # Evaluate the rule
-    argspec = getargspec(rule.__call__)
+    argspec = inspect.getfullargspec(rule.__call__)
     rule_args = [target, creds, enforcer]
     # Check if the rule argument must be included or not
     if len(argspec.args) > 4:
@@ -86,10 +79,11 @@ def _check(rule, target, creds, enforcer, current_rule):
     return rule(*rule_args)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BaseCheck(object):
+class BaseCheck(metaclass=abc.ABCMeta):
     """Abstract base class for Check classes."""
 
+    scope_types = None
+
     @abc.abstractmethod
     def __str__(self):
         """String representation of the Check tree rooted at this node."""
@@ -143,7 +137,7 @@ class Check(BaseCheck):
     def __str__(self):
         """Return a string representation of this check."""
 
-        return '%s:%s' % (self.kind, self.match)
+        return '{}:{}'.format(self.kind, self.match)
 
 
 class NotCheck(BaseCheck):
@@ -316,7 +310,7 @@ class GenericCheck(Check):
         '''
 
         if len(path_segments) == 0:
-            return match == six.text_type(test_value)
+            return match == str(test_value)
         key, path_segments = path_segments[0], path_segments[1:]
         try:
             test_value = test_value[key]
@@ -341,7 +335,7 @@ class GenericCheck(Check):
         try:
             # Try to interpret self.kind as a literal
             test_value = ast.literal_eval(self.kind)
-            return match == six.text_type(test_value)
+            return match == str(test_value)
 
         except ValueError:
             pass
